DeepSeek-V3’s engineers optimized GPU performance at the low-level by tailoring kernels and memory access patterns to NVIDIA’s hardware. A key strategy was warp specialization: they partitioned a subset of GPU threads (warps) specifically for communication tasks, allowing compute to overlap with data transfers (DeepSeek-V3 Technical Report). In practice, only ~20 of the GPU’s Streaming Multiprocessors (SMs) were reserved to handle all cross-node communications – enough to saturate both InfiniBand (IB) and NVLink bandwidth – while the remaining SMs focused purely on computation (DeepSeek-V3 Technical Report) ([DeepSeek-V3 Technical Report](https://arx
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
| # ~/.tmux.conf | |
| # General settings | |
| set -g default-terminal "screen-256color" # Use 256-color terminal | |
| set -g history-limit 5000 # Increase scrollback buffer size | |
| set -g base-index 0 # Start window indexes at 0 | |
| set -g mouse on # Enable mouse control (pane selection, resizing, scrolling) | |
| # Restore original prefix key | |
| set-option -g prefix C-b # Set prefix to Ctrl-b |
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
| #include <iostream> | |
| #include <cuda.h> | |
| // CUDA Kernel | |
| __global__ void add_arrays(float *a, float *b, float *c, int n) { | |
| int idx = blockIdx.x * blockDim.x + threadIdx.x; | |
| if (idx < n) { | |
| c[idx] = a[idx] + b[idx]; | |
| } |
Loading
Sorry, something went wrong. Reload?
Sorry, we cannot display this file.
Sorry, this file is invalid so it cannot be displayed.
Loading
Sorry, something went wrong. Reload?
Sorry, we cannot display this file.
Sorry, this file is invalid so it cannot be displayed.
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
| <!DOCTYPE html> | |
| <html lang="en"> | |
| <head> | |
| <meta charset="UTF-8"> | |
| <meta name="viewport" content="width=device-width, initial-scale=1.0"> | |
| <title>Horizontal Binary Clock</title> | |
| <style> | |
| body { | |
| background-color: #1a1a1a; | |
| /* Center the main wrapper on the page */ |
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
| set -g terminal-overrides 'xterm*:smcup@:rmcup@' | |
| # ~/.tmux.conf | |
| # for tmux 3.5a | |
| # | |
| # ----------------------------------------------------------------------------- | |
| # Global settings | |
| # Set prefix key to Ctrl-a | |
| #unbind-key C-b |
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
| QEMU ?= qemu-system-x86_64 | |
| UBUNTU_INSTALL_CDROM ?= ~/Downloads/ubuntu-24.04.3-desktop-amd64.iso | |
| DISK ?= disk/disk.qcow2 | |
| RAM ?= 32768 | |
| CPUS ?= 16 | |
| PORT ?= 2222 | |
| DISPLAY_WIDTH ?= 1920 | |
| DISPLAY_HEIGHT ?= 1080 | |
| # QXL for stable single display (defaults) |
| name | cove-validate |
|---|---|
| description | Chain-of-Verification validation for any claim, output, plan, or code change. Use when the user says "validate", "verify", "check this", "is this right", "CoVe", or when you need to rigorously verify correctness of something before presenting it as fact. Also use proactively before committing code, finalizing plans, or asserting factual claims that could be wrong. |
Apply the Chain-of-Verification (CoVe) framework to rigorously validate a target claim, output, or artifact. CoVe works by generating independent verification questions and answering them without bias from the original draft, then synthesizing a verified result.
- User explicitly asks to validate/verify something
OlderNewer